============
Contributing
============

Ideally create a topic branch for every separate change you make. Each logical change should be its own separate pull request. For example:


#. Fork the repository.
#. Create a  branch (\ ``git checkout -b feature/my-new-feature``\ , ``git checkout -b fix/my-fix``\ )
#. Add and commit your changes to your fork (\ ``git commit -m 'Added some feature'``\ )
#. Push to your fork (\ ``git push origin feature/my-new-feature``\ )
#. Create new Pull Request from your fork onto the tokendito repo
#. Assign the PR to a team member.

See `GitHub Flow <https://guides.github.com/introduction/flow/>`_

Git commit messages
^^^^^^^^^^^^^^^^^^^


* Separate subject from body with a blank line
* Limit the subject line to 50 characters
* Capitalize the subject line
* Do not end the subject line with a period
* Use the imperative mood in the subject line
* Wrap the body at 72 characters
* Use the body to explain what and why vs. how

See best practices on `commit messages <https://chris.beams.io/posts/git-commit/>`_
